==> openshift-model-6.6.2-sources.jar: io/fabric8/openshift/api/model/BuildTriggerPolicyFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class BuildTriggerPolicyFluentImpl<A extends BuildTriggerPolicyFluent<A>> extends BaseFluent<A> implements BuildTriggerPolicyFluent<A>{
  public BuildTriggerPolicyFluentImpl() {
  }
  public BuildTriggerPolicyFluentImpl(BuildTriggerPolicy instance) {
    this.withBitbucket(instance.getBitbucket()); 
    this.withGeneric(instance.getGeneric()); 
    this.withGithub(instance.getGithub()); 
    this.withGitlab(instance.getGitlab()); 
    this.withImageChange(instance.getImageChange()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private WebHookTriggerBuilder bitbucket;
  private WebHookTriggerBuilder generic;
  private WebHookTriggerBuilder github;
  private WebHookTriggerBuilder gitlab;
  private ImageChangeTriggerBuilder imageChange;
  private String type;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildBitbucket instead.
   * @return The buildable object.
   */
  @Deprecated
  public WebHookTrigger getBitbucket() {
    return this.bitbucket!=null ?this.bitbucket.build():null;
  }
  public WebHookTrigger buildBitbucket() {
    return this.bitbucket!=null ?this.bitbucket.build():null;
  }
  public A withBitbucket(WebHookTrigger bitbucket) {
    _visitables.get("bitbucket").remove(this.bitbucket);
    if (bitbucket!=null){ this.bitbucket= new WebHookTriggerBuilder(bitbucket); _visitables.get("bitbucket").add(this.bitbucket);} else { this.bitbucket = null; _visitables.get("bitbucket").remove(this.bitbucket); } return (A) this;
  }
  public Boolean hasBitbucket() {
    return this.bitbucket != null;
  }
  public BuildTriggerPolicyFluent.BitbucketNested<A> withNewBitbucket() {
    return new BuildTriggerPolicyFluentImpl.BitbucketNestedImpl();
  }
  public BuildTriggerPolicyFluent.BitbucketNested<A> withNewBitbucketLike(WebHookTrigger item) {
    return new BuildTriggerPolicyFluentImpl.BitbucketNestedImpl(item);
  }
  public BuildTriggerPolicyFluent.BitbucketNested<A> editBitbucket() {
    return withNewBitbucketLike(getBitbucket());
  }
  public BuildTriggerPolicyFluent.BitbucketNested<A> editOrNewBitbucket() {
    return withNewBitbucketLike(getBitbucket() != null ? getBitbucket(): new WebHookTriggerBuilder().build());
  }
  public BuildTriggerPolicyFluent.BitbucketNested<A> editOrNewBitbucketLike(WebHookTrigger item) {
    return withNewBitbucketLike(getBitbucket() != null ? getBitbucket(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildGeneric instead.
   * @return The buildable object.
   */
  @Deprecated
  public WebHookTrigger getGeneric() {
    return this.generic!=null ?this.generic.build():null;
  }
  public WebHookTrigger buildGeneric() {
    return this.generic!=null ?this.generic.build():null;
  }
  public A withGeneric(WebHookTrigger generic) {
    _visitables.get("generic").remove(this.generic);
    if (generic!=null){ this.generic= new WebHookTriggerBuilder(generic); _visitables.get("generic").add(this.generic);} else { this.generic = null; _visitables.get("generic").remove(this.generic); } return (A) this;
  }
  public Boolean hasGeneric() {
    return this.generic != null;
  }
  public BuildTriggerPolicyFluent.GenericNested<A> withNewGeneric() {
    return new BuildTriggerPolicyFluentImpl.GenericNestedImpl();
  }
  public BuildTriggerPolicyFluent.GenericNested<A> withNewGenericLike(WebHookTrigger item) {
    return new BuildTriggerPolicyFluentImpl.GenericNestedImpl(item);
  }
  public BuildTriggerPolicyFluent.GenericNested<A> editGeneric() {
    return withNewGenericLike(getGeneric());
  }
  public BuildTriggerPolicyFluent.GenericNested<A> editOrNewGeneric() {
    return withNewGenericLike(getGeneric() != null ? getGeneric(): new WebHookTriggerBuilder().build());
  }
  public BuildTriggerPolicyFluent.GenericNested<A> editOrNewGenericLike(WebHookTrigger item) {
    return withNewGenericLike(getGeneric() != null ? getGeneric(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildGithub instead.
   * @return The buildable object.
   */
  @Deprecated
  public WebHookTrigger getGithub() {
    return this.github!=null ?this.github.build():null;
  }
  public WebHookTrigger buildGithub() {
    return this.github!=null ?this.github.build():null;
  }
  public A withGithub(WebHookTrigger github) {
    _visitables.get("github").remove(this.github);
    if (github!=null){ this.github= new WebHookTriggerBuilder(github); _visitables.get("github").add(this.github);} else { this.github = null; _visitables.get("github").remove(this.github); } return (A) this;
  }
  public Boolean hasGithub() {
    return this.github != null;
  }
  public BuildTriggerPolicyFluent.GithubNested<A> withNewGithub() {
    return new BuildTriggerPolicyFluentImpl.GithubNestedImpl();
  }
  public BuildTriggerPolicyFluent.GithubNested<A> withNewGithubLike(WebHookTrigger item) {
    return new BuildTriggerPolicyFluentImpl.GithubNestedImpl(item);
  }
  public BuildTriggerPolicyFluent.GithubNested<A> editGithub() {
    return withNewGithubLike(getGithub());
  }
  public BuildTriggerPolicyFluent.GithubNested<A> editOrNewGithub() {
    return withNewGithubLike(getGithub() != null ? getGithub(): new WebHookTriggerBuilder().build());
  }
  public BuildTriggerPolicyFluent.GithubNested<A> editOrNewGithubLike(WebHookTrigger item) {
    return withNewGithubLike(getGithub() != null ? getGithub(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildGitlab instead.
   * @return The buildable object.
   */
  @Deprecated
  public WebHookTrigger getGitlab() {
    return this.gitlab!=null ?this.gitlab.build():null;
  }
  public WebHookTrigger buildGitlab() {
    return this.gitlab!=null ?this.gitlab.build():null;
  }
  public A withGitlab(WebHookTrigger gitlab) {
    _visitables.get("gitlab").remove(this.gitlab);
    if (gitlab!=null){ this.gitlab= new WebHookTriggerBuilder(gitlab); _visitables.get("gitlab").add(this.gitlab);} else { this.gitlab = null; _visitables.get("gitlab").remove(this.gitlab); } return (A) this;
  }
  public Boolean hasGitlab() {
    return this.gitlab != null;
  }
  public BuildTriggerPolicyFluent.GitlabNested<A> withNewGitlab() {
    return new BuildTriggerPolicyFluentImpl.GitlabNestedImpl();
  }
  public BuildTriggerPolicyFluent.GitlabNested<A> withNewGitlabLike(WebHookTrigger item) {
    return new BuildTriggerPolicyFluentImpl.GitlabNestedImpl(item);
  }
  public BuildTriggerPolicyFluent.GitlabNested<A> editGitlab() {
    return withNewGitlabLike(getGitlab());
  }
  public BuildTriggerPolicyFluent.GitlabNested<A> editOrNewGitlab() {
    return withNewGitlabLike(getGitlab() != null ? getGitlab(): new WebHookTriggerBuilder().build());
  }
  public BuildTriggerPolicyFluent.GitlabNested<A> editOrNewGitlabLike(WebHookTrigger item) {
    return withNewGitlabLike(getGitlab() != null ? getGitlab(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildImageChange instead.
   * @return The buildable object.
   */
  @Deprecated
  public ImageChangeTrigger getImageChange() {
    return this.imageChange!=null ?this.imageChange.build():null;
  }
  public ImageChangeTrigger buildImageChange() {
    return this.imageChange!=null ?this.imageChange.build():null;
  }
  public A withImageChange(ImageChangeTrigger imageChange) {
    _visitables.get("imageChange").remove(this.imageChange);
    if (imageChange!=null){ this.imageChange= new ImageChangeTriggerBuilder(imageChange); _visitables.get("imageChange").add(this.imageChange);} else { this.imageChange = null; _visitables.get("imageChange").remove(this.imageChange); } return (A) this;
  }
  public Boolean hasImageChange() {
    return this.imageChange != null;
  }
  public BuildTriggerPolicyFluent.ImageChangeNested<A> withNewImageChange() {
    return new BuildTriggerPolicyFluentImpl.ImageChangeNestedImpl();
  }
  public BuildTriggerPolicyFluent.ImageChangeNested<A> withNewImageChangeLike(ImageChangeTrigger item) {
    return new BuildTriggerPolicyFluentImpl.ImageChangeNestedImpl(item);
  }
  public BuildTriggerPolicyFluent.ImageChangeNested<A> editImageChange() {
    return withNewImageChangeLike(getImageChange());
  }
  public BuildTriggerPolicyFluent.ImageChangeNested<A> editOrNewImageChange() {
    return withNewImageChangeLike(getImageChange() != null ? getImageChange(): new ImageChangeTriggerBuilder().build());
  }
  public BuildTriggerPolicyFluent.ImageChangeNested<A> editOrNewImageChangeLike(ImageChangeTrigger item) {
    return withNewImageChangeLike(getImageChange() != null ? getImageChange(): item);
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    BuildTriggerPolicyFluentImpl that = (BuildTriggerPolicyFluentImpl) o;
    if (bitbucket != null ? !bitbucket.equals(that.bitbucket) :that.bitbucket != null) return false;
    if (generic != null ? !generic.equals(that.generic) :that.generic != null) return false;
    if (github != null ? !github.equals(that.github) :that.github != null) return false;
    if (gitlab != null ? !gitlab.equals(that.gitlab) :that.gitlab != null) return false;
    if (imageChange != null ? !imageChange.equals(that.imageChange) :that.imageChange != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(bitbucket,  generic,  github,  gitlab,  imageChange,  type,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (bitbucket != null) { sb.append("bitbucket:"); sb.append(bitbucket + ","); }
    if (generic != null) { sb.append("generic:"); sb.append(generic + ","); }
    if (github != null) { sb.append("github:"); sb.append(github + ","); }
    if (gitlab != null) { sb.append("gitlab:"); sb.append(gitlab + ","); }
    if (imageChange != null) { sb.append("imageChange:"); sb.append(imageChange + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class BitbucketNestedImpl<N> extends WebHookTriggerFluentImpl<BuildTriggerPolicyFluent.BitbucketNested<N>> implements BuildTriggerPolicyFluent.BitbucketNested<N>,Nested<N>{
    BitbucketNestedImpl(WebHookTrigger item) {
      this.builder = new WebHookTriggerBuilder(this, item);
    }
    BitbucketNestedImpl() {
      this.builder = new WebHookTriggerBuilder(this);
    }
    WebHookTriggerBuilder builder;
    public N and() {
      return (N) BuildTriggerPolicyFluentImpl.this.withBitbucket(builder.build());
    }
    public N endBitbucket() {
      return and();
    }
    
  }
  class GenericNestedImpl<N> extends WebHookTriggerFluentImpl<BuildTriggerPolicyFluent.GenericNested<N>> implements BuildTriggerPolicyFluent.GenericNested<N>,Nested<N>{
    GenericNestedImpl(WebHookTrigger item) {
      this.builder = new WebHookTriggerBuilder(this, item);
    }
    GenericNestedImpl() {
      this.builder = new WebHookTriggerBuilder(this);
    }
    WebHookTriggerBuilder builder;
    public N and() {
      return (N) BuildTriggerPolicyFluentImpl.this.withGeneric(builder.build());
    }
    public N endGeneric() {
      return and();
    }
    
  }
  class GithubNestedImpl<N> extends WebHookTriggerFluentImpl<BuildTriggerPolicyFluent.GithubNested<N>> implements BuildTriggerPolicyFluent.GithubNested<N>,Nested<N>{
    GithubNestedImpl(WebHookTrigger item) {
      this.builder = new WebHookTriggerBuilder(this, item);
    }
    GithubNestedImpl() {
      this.builder = new WebHookTriggerBuilder(this);
    }
    WebHookTriggerBuilder builder;
    public N and() {
      return (N) BuildTriggerPolicyFluentImpl.this.withGithub(builder.build());
    }
    public N endGithub() {
      return and();
    }
    
  }
  class GitlabNestedImpl<N> extends WebHookTriggerFluentImpl<BuildTriggerPolicyFluent.GitlabNested<N>> implements BuildTriggerPolicyFluent.GitlabNested<N>,Nested<N>{
    GitlabNestedImpl(WebHookTrigger item) {
      this.builder = new WebHookTriggerBuilder(this, item);
    }
    GitlabNestedImpl() {
      this.builder = new WebHookTriggerBuilder(this);
    }
    WebHookTriggerBuilder builder;
    public N and() {
      return (N) BuildTriggerPolicyFluentImpl.this.withGitlab(builder.build());
    }
    public N endGitlab() {
      return and();
    }
    
  }
  class ImageChangeNestedImpl<N> extends ImageChangeTriggerFluentImpl<BuildTriggerPolicyFluent.ImageChangeNested<N>> implements BuildTriggerPolicyFluent.ImageChangeNested<N>,Nested<N>{
    ImageChangeNestedImpl(ImageChangeTrigger item) {
      this.builder = new ImageChangeTriggerBuilder(this, item);
    }
    ImageChangeNestedImpl() {
      this.builder = new ImageChangeTriggerBuilder(this);
    }
    ImageChangeTriggerBuilder builder;
    public N and() {
      return (N) BuildTriggerPolicyFluentImpl.this.withImageChange(builder.build());
    }
    public N endImageChange() {
      return and();
    }
    
  }
  
}

==> openshift-model-6.7.1-sources.jar: io/fabric8/openshift/api/model/BuildTriggerPolicyFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class BuildTriggerPolicyFluentImpl<A extends BuildTriggerPolicyFluent<A>> extends BaseFluent<A> implements BuildTriggerPolicyFluent<A>{
  public BuildTriggerPolicyFluentImpl() {
  }
  public BuildTriggerPolicyFluentImpl(BuildTriggerPolicy instance) {
    if (instance != null) {
      this.withBitbucket(instance.getBitbucket());
      this.withGeneric(instance.getGeneric());
      this.withGithub(instance.getGithub());
      this.withGitlab(instance.getGitlab());
      this.withImageChange(instance.getImageChange());
      this.withType(instance.getType());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private WebHookTriggerBuilder bitbucket;
  private WebHookTriggerBuilder generic;
  private WebHookTriggerBuilder github;
  private WebHookTriggerBuilder gitlab;
  private ImageChangeTriggerBuilder imageChange;
  private String type;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildBitbucket instead.
   * @return The buildable object.
   */
  @Deprecated
  public WebHookTrigger getBitbucket() {
    return this.bitbucket!=null ?this.bitbucket.build():null;
  }
  public WebHookTrigger buildBitbucket() {
    return this.bitbucket!=null ?this.bitbucket.build():null;
  }
  public A withBitbucket(WebHookTrigger bitbucket) {
    _visitables.get("bitbucket").remove(this.bitbucket);
    if (bitbucket!=null){ this.bitbucket= new WebHookTriggerBuilder(bitbucket); _visitables.get("bitbucket").add(this.bitbucket);} else { this.bitbucket = null; _visitables.get("bitbucket").remove(this.bitbucket); } return (A) this;
  }
  public Boolean hasBitbucket() {
    return this.bitbucket != null;
  }
  public BuildTriggerPolicyFluentImpl.BitbucketNested<A> withNewBitbucket() {
    return new BuildTriggerPolicyFluentImpl.BitbucketNestedImpl();
  }
  public BuildTriggerPolicyFluentImpl.BitbucketNested<A> withNewBitbucketLike(WebHookTrigger item) {
    return new BuildTriggerPolicyFluentImpl.BitbucketNestedImpl(item);
  }
  public BuildTriggerPolicyFluentImpl.BitbucketNested<A> editBitbucket() {
    return withNewBitbucketLike(getBitbucket());
  }
  public BuildTriggerPolicyFluentImpl.BitbucketNested<A> editOrNewBitbucket() {
    return withNewBitbucketLike(getBitbucket() != null ? getBitbucket(): new WebHookTriggerBuilder().build());
  }
  public BuildTriggerPolicyFluentImpl.BitbucketNested<A> editOrNewBitbucketLike(WebHookTrigger item) {
    return withNewBitbucketLike(getBitbucket() != null ? getBitbucket(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildGeneric instead.
   * @return The buildable object.
   */
  @Deprecated
  public WebHookTrigger getGeneric() {
    return this.generic!=null ?this.generic.build():null;
  }
  public WebHookTrigger buildGeneric() {
    return this.generic!=null ?this.generic.build():null;
  }
  public A withGeneric(WebHookTrigger generic) {
    _visitables.get("generic").remove(this.generic);
    if (generic!=null){ this.generic= new WebHookTriggerBuilder(generic); _visitables.get("generic").add(this.generic);} else { this.generic = null; _visitables.get("generic").remove(this.generic); } return (A) this;
  }
  public Boolean hasGeneric() {
    return this.generic != null;
  }
  public BuildTriggerPolicyFluentImpl.GenericNested<A> withNewGeneric() {
    return new BuildTriggerPolicyFluentImpl.GenericNestedImpl();
  }
  public BuildTriggerPolicyFluentImpl.GenericNested<A> withNewGenericLike(WebHookTrigger item) {
    return new BuildTriggerPolicyFluentImpl.GenericNestedImpl(item);
  }
  public BuildTriggerPolicyFluentImpl.GenericNested<A> editGeneric() {
    return withNewGenericLike(getGeneric());
  }
  public BuildTriggerPolicyFluentImpl.GenericNested<A> editOrNewGeneric() {
    return withNewGenericLike(getGeneric() != null ? getGeneric(): new WebHookTriggerBuilder().build());
  }
  public BuildTriggerPolicyFluentImpl.GenericNested<A> editOrNewGenericLike(WebHookTrigger item) {
    return withNewGenericLike(getGeneric() != null ? getGeneric(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildGithub instead.
   * @return The buildable object.
   */
  @Deprecated
  public WebHookTrigger getGithub() {
    return this.github!=null ?this.github.build():null;
  }
  public WebHookTrigger buildGithub() {
    return this.github!=null ?this.github.build():null;
  }
  public A withGithub(WebHookTrigger github) {
    _visitables.get("github").remove(this.github);
    if (github!=null){ this.github= new WebHookTriggerBuilder(github); _visitables.get("github").add(this.github);} else { this.github = null; _visitables.get("github").remove(this.github); } return (A) this;
  }
  public Boolean hasGithub() {
    return this.github != null;
  }
  public BuildTriggerPolicyFluentImpl.GithubNested<A> withNewGithub() {
    return new BuildTriggerPolicyFluentImpl.GithubNestedImpl();
  }
  public BuildTriggerPolicyFluentImpl.GithubNested<A> withNewGithubLike(WebHookTrigger item) {
    return new BuildTriggerPolicyFluentImpl.GithubNestedImpl(item);
  }
  public BuildTriggerPolicyFluentImpl.GithubNested<A> editGithub() {
    return withNewGithubLike(getGithub());
  }
  public BuildTriggerPolicyFluentImpl.GithubNested<A> editOrNewGithub() {
    return withNewGithubLike(getGithub() != null ? getGithub(): new WebHookTriggerBuilder().build());
  }
  public BuildTriggerPolicyFluentImpl.GithubNested<A> editOrNewGithubLike(WebHookTrigger item) {
    return withNewGithubLike(getGithub() != null ? getGithub(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildGitlab instead.
   * @return The buildable object.
   */
  @Deprecated
  public WebHookTrigger getGitlab() {
    return this.gitlab!=null ?this.gitlab.build():null;
  }
  public WebHookTrigger buildGitlab() {
    return this.gitlab!=null ?this.gitlab.build():null;
  }
  public A withGitlab(WebHookTrigger gitlab) {
    _visitables.get("gitlab").remove(this.gitlab);
    if (gitlab!=null){ this.gitlab= new WebHookTriggerBuilder(gitlab); _visitables.get("gitlab").add(this.gitlab);} else { this.gitlab = null; _visitables.get("gitlab").remove(this.gitlab); } return (A) this;
  }
  public Boolean hasGitlab() {
    return this.gitlab != null;
  }
  public BuildTriggerPolicyFluentImpl.GitlabNested<A> withNewGitlab() {
    return new BuildTriggerPolicyFluentImpl.GitlabNestedImpl();
  }
  public BuildTriggerPolicyFluentImpl.GitlabNested<A> withNewGitlabLike(WebHookTrigger item) {
    return new BuildTriggerPolicyFluentImpl.GitlabNestedImpl(item);
  }
  public BuildTriggerPolicyFluentImpl.GitlabNested<A> editGitlab() {
    return withNewGitlabLike(getGitlab());
  }
  public BuildTriggerPolicyFluentImpl.GitlabNested<A> editOrNewGitlab() {
    return withNewGitlabLike(getGitlab() != null ? getGitlab(): new WebHookTriggerBuilder().build());
  }
  public BuildTriggerPolicyFluentImpl.GitlabNested<A> editOrNewGitlabLike(WebHookTrigger item) {
    return withNewGitlabLike(getGitlab() != null ? getGitlab(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildImageChange instead.
   * @return The buildable object.
   */
  @Deprecated
  public ImageChangeTrigger getImageChange() {
    return this.imageChange!=null ?this.imageChange.build():null;
  }
  public ImageChangeTrigger buildImageChange() {
    return this.imageChange!=null ?this.imageChange.build():null;
  }
  public A withImageChange(ImageChangeTrigger imageChange) {
    _visitables.get("imageChange").remove(this.imageChange);
    if (imageChange!=null){ this.imageChange= new ImageChangeTriggerBuilder(imageChange); _visitables.get("imageChange").add(this.imageChange);} else { this.imageChange = null; _visitables.get("imageChange").remove(this.imageChange); } return (A) this;
  }
  public Boolean hasImageChange() {
    return this.imageChange != null;
  }
  public BuildTriggerPolicyFluentImpl.ImageChangeNested<A> withNewImageChange() {
    return new BuildTriggerPolicyFluentImpl.ImageChangeNestedImpl();
  }
  public BuildTriggerPolicyFluentImpl.ImageChangeNested<A> withNewImageChangeLike(ImageChangeTrigger item) {
    return new BuildTriggerPolicyFluentImpl.ImageChangeNestedImpl(item);
  }
  public BuildTriggerPolicyFluentImpl.ImageChangeNested<A> editImageChange() {
    return withNewImageChangeLike(getImageChange());
  }
  public BuildTriggerPolicyFluentImpl.ImageChangeNested<A> editOrNewImageChange() {
    return withNewImageChangeLike(getImageChange() != null ? getImageChange(): new ImageChangeTriggerBuilder().build());
  }
  public BuildTriggerPolicyFluentImpl.ImageChangeNested<A> editOrNewImageChangeLike(ImageChangeTrigger item) {
    return withNewImageChangeLike(getImageChange() != null ? getImageChange(): item);
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    BuildTriggerPolicyFluentImpl that = (BuildTriggerPolicyFluentImpl) o;
    if (!java.util.Objects.equals(bitbucket, that.bitbucket)) return false;

    if (!java.util.Objects.equals(generic, that.generic)) return false;

    if (!java.util.Objects.equals(github, that.github)) return false;

    if (!java.util.Objects.equals(gitlab, that.gitlab)) return false;

    if (!java.util.Objects.equals(imageChange, that.imageChange)) return false;

    if (!java.util.Objects.equals(type, that.type)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(bitbucket,  generic,  github,  gitlab,  imageChange,  type,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (bitbucket != null) { sb.append("bitbucket:"); sb.append(bitbucket + ","); }
    if (generic != null) { sb.append("generic:"); sb.append(generic + ","); }
    if (github != null) { sb.append("github:"); sb.append(github + ","); }
    if (gitlab != null) { sb.append("gitlab:"); sb.append(gitlab + ","); }
    if (imageChange != null) { sb.append("imageChange:"); sb.append(imageChange + ","); }
    if (type != null) { sb.append("type:"); sb.append(type + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class BitbucketNestedImpl<N> extends WebHookTriggerFluentImpl<BuildTriggerPolicyFluentImpl.BitbucketNested<N>> implements BuildTriggerPolicyFluentImpl.BitbucketNested<N>,Nested<N>{
    BitbucketNestedImpl(WebHookTrigger item) {
      this.builder = new WebHookTriggerBuilder(this, item);
    }
    BitbucketNestedImpl() {
      this.builder = new WebHookTriggerBuilder(this);
    }
    WebHookTriggerBuilder builder;
    public N and() {
      return (N) BuildTriggerPolicyFluentImpl.this.withBitbucket(builder.build());
    }
    public N endBitbucket() {
      return and();
    }
    
  }
  class GenericNestedImpl<N> extends WebHookTriggerFluentImpl<BuildTriggerPolicyFluentImpl.GenericNested<N>> implements BuildTriggerPolicyFluentImpl.GenericNested<N>,Nested<N>{
    GenericNestedImpl(WebHookTrigger item) {
      this.builder = new WebHookTriggerBuilder(this, item);
    }
    GenericNestedImpl() {
      this.builder = new WebHookTriggerBuilder(this);
    }
    WebHookTriggerBuilder builder;
    public N and() {
      return (N) BuildTriggerPolicyFluentImpl.this.withGeneric(builder.build());
    }
    public N endGeneric() {
      return and();
    }
    
  }
  class GithubNestedImpl<N> extends WebHookTriggerFluentImpl<BuildTriggerPolicyFluentImpl.GithubNested<N>> implements BuildTriggerPolicyFluentImpl.GithubNested<N>,Nested<N>{
    GithubNestedImpl(WebHookTrigger item) {
      this.builder = new WebHookTriggerBuilder(this, item);
    }
    GithubNestedImpl() {
      this.builder = new WebHookTriggerBuilder(this);
    }
    WebHookTriggerBuilder builder;
    public N and() {
      return (N) BuildTriggerPolicyFluentImpl.this.withGithub(builder.build());
    }
    public N endGithub() {
      return and();
    }
    
  }
  class GitlabNestedImpl<N> extends WebHookTriggerFluentImpl<BuildTriggerPolicyFluentImpl.GitlabNested<N>> implements BuildTriggerPolicyFluentImpl.GitlabNested<N>,Nested<N>{
    GitlabNestedImpl(WebHookTrigger item) {
      this.builder = new WebHookTriggerBuilder(this, item);
    }
    GitlabNestedImpl() {
      this.builder = new WebHookTriggerBuilder(this);
    }
    WebHookTriggerBuilder builder;
    public N and() {
      return (N) BuildTriggerPolicyFluentImpl.this.withGitlab(builder.build());
    }
    public N endGitlab() {
      return and();
    }
    
  }
  class ImageChangeNestedImpl<N> extends ImageChangeTriggerFluentImpl<BuildTriggerPolicyFluentImpl.ImageChangeNested<N>> implements BuildTriggerPolicyFluentImpl.ImageChangeNested<N>,Nested<N>{
    ImageChangeNestedImpl(ImageChangeTrigger item) {
      this.builder = new ImageChangeTriggerBuilder(this, item);
    }
    ImageChangeNestedImpl() {
      this.builder = new ImageChangeTriggerBuilder(this);
    }
    ImageChangeTriggerBuilder builder;
    public N and() {
      return (N) BuildTriggerPolicyFluentImpl.this.withImageChange(builder.build());
    }
    public N endImageChange() {
      return and();
    }
    
  }
  
}
